@@ -47,6 +47,14 @@ typedef struct menu_entry_s {
   };
 } menu_entry_t;
 
+static gboolean menu_get_active(GtkWidget *item) {
+#ifdef MAEMO5
+  return hildon_check_button_get_active(HILDON_CHECK_BUTTON(item));
+#else
+  return gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(item));
+#endif
+}
+
 static void 
 cb_menu_about(GtkWidget *item, gpointer data) {
   GtkWidget *toplevel = gtk_widget_get_toplevel(GTK_WIDGET(data));
@@ -55,8 +63,12 @@ cb_menu_about(GtkWidget *item, gpointer data) {
 
 static void 
 cb_menu_search(GtkWidget *item, gpointer data) {
-  GtkWidget *toplevel = gtk_widget_get_toplevel(GTK_WIDGET(data));
-  geonames_enable_search(toplevel, GTK_WIDGET(data));
+  geonames_enable_search(GTK_WIDGET(data));
+}
+
+static void 
+cb_menu_wikipedia(GtkWidget *item, gpointer data) {
+  geonames_enable_wikipedia(GTK_WIDGET(data), menu_get_active(item)); 
 }
 
 static void 
@@ -69,14 +81,6 @@ cb_menu_track_clear(GtkWidget *item, gpointer data) {
   track_clear(GTK_WIDGET(data));
 }
 
-static gboolean menu_get_active(GtkWidget *item) {
-#ifdef MAEMO5
-  return hildon_check_button_get_active(HILDON_CHECK_BUTTON(item));
-#else
-  return gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(item));
-#endif
-}
-
 static void 
 cb_menu_track_capture(GtkWidget *item, gpointer data) {
   track_capture_enable(GTK_WIDGET(data), menu_get_active(item)); 
@@ -88,22 +92,23 @@ cb_menu_track_export(GtkWidget *item, gpointer data) {
 }
 
 static const menu_entry_t track_menu[] = {
-  { MENU_CHECK_ENTRY, "Capture", { .cb = cb_menu_track_capture } },
-  { MENU_ENTRY,       "Clear",   { .cb = cb_menu_track_clear } } ,
-  { MENU_ENTRY,       "Import",  { .cb = cb_menu_track_import } },
-  { MENU_ENTRY,       "Export",  { .cb = cb_menu_track_export } },
+  { MENU_CHECK_ENTRY, "Capture",   { .cb = cb_menu_track_capture } },
+  { MENU_ENTRY,       "Clear",     { .cb = cb_menu_track_clear } } ,
+  { MENU_ENTRY,       "Import",    { .cb = cb_menu_track_import } },
+  { MENU_ENTRY,       "Export",    { .cb = cb_menu_track_export } },
 
-  { MENU_END,         NULL,      { NULL } }
+  { MENU_END,         NULL,        { NULL } }
 };
 
 static const menu_entry_t main_menu[] = {
-  { MENU_ENTRY,       "About",  { .cb = cb_menu_about } },
-  { MENU_SEPARATOR,   NULL,     { NULL } },
-  { MENU_SUBMENU,     "Track",  { .submenu = track_menu } },
-  { MENU_SEPARATOR,   NULL,     { NULL } },
-  { MENU_ENTRY,       "Search", { .cb = cb_menu_search } },
+  { MENU_ENTRY,       "About",     { .cb = cb_menu_about } },
+  { MENU_SEPARATOR,   NULL,        { NULL } },
+  { MENU_SUBMENU,     "Track",     { .submenu = track_menu } },
+  { MENU_SEPARATOR,   NULL,        { NULL } },
+  { MENU_ENTRY,       "Search",    { .cb = cb_menu_search } },
+  { MENU_CHECK_ENTRY, "Wikipedia", { .cb = cb_menu_wikipedia } },
 
-  { MENU_END,         NULL,     { NULL } }
+  { MENU_END,         NULL,        { NULL } }
 };
 
 #ifdef MAEMO5
