@@ -66,26 +66,39 @@ typedef enum {
     OSM_GPS_MAP_SOURCE_NULL,
     OSM_GPS_MAP_SOURCE_OPENSTREETMAP,
     OSM_GPS_MAP_SOURCE_OPENSTREETMAP_RENDERER,
+    OSM_GPS_MAP_SOURCE_OPENAERIALMAP,
+    OSM_GPS_MAP_SOURCE_MAPS_FOR_FREE,
     OSM_GPS_MAP_SOURCE_OPENCYCLEMAP,
     OSM_GPS_MAP_SOURCE_OSM_PUBLIC_TRANSPORT,
     OSM_GPS_MAP_SOURCE_GOOGLE_STREET,
+    OSM_GPS_MAP_SOURCE_GOOGLE_SATELLITE,
+    OSM_GPS_MAP_SOURCE_GOOGLE_HYBRID,
     OSM_GPS_MAP_SOURCE_VIRTUAL_EARTH_STREET,
     OSM_GPS_MAP_SOURCE_VIRTUAL_EARTH_SATELLITE,
     OSM_GPS_MAP_SOURCE_VIRTUAL_EARTH_HYBRID,
+    OSM_GPS_MAP_SOURCE_YAHOO_STREET,
+    OSM_GPS_MAP_SOURCE_YAHOO_SATELLITE,
+    OSM_GPS_MAP_SOURCE_YAHOO_HYBRID,
+    OSM_GPS_MAP_SOURCE_OSMC_TRAILS,
 
-    /* entries below are currently unusable */
-    OSM_GPS_MAP_SOURCE_OSMC_TRAILS,      /* only germany       */
-    OSM_GPS_MAP_SOURCE_MAPS_FOR_FREE,    /* not enough details */
-    OSM_GPS_MAP_SOURCE_GOOGLE_HYBRID,    /* disabled by google */
-    OSM_GPS_MAP_SOURCE_GOOGLE_SATELLITE, /* disabled by google */
-    OSM_GPS_MAP_SOURCE_YAHOO_STREET,     /* no implemented yet */
-    OSM_GPS_MAP_SOURCE_YAHOO_SATELLITE,  /* no implemented yet */
-    OSM_GPS_MAP_SOURCE_YAHOO_HYBRID      /* no implemented yet */
+    OSM_GPS_MAP_SOURCE_LAST
 } OsmGpsMapSource_t;
 
-#define OSM_GPS_MAP_SOURCE_LAST  (OSM_GPS_MAP_SOURCE_VIRTUAL_EARTH_HYBRID)
+typedef enum {
+    OSM_GPS_MAP_KEY_FULLSCREEN,
+    OSM_GPS_MAP_KEY_ZOOMIN,
+    OSM_GPS_MAP_KEY_ZOOMOUT,
+    OSM_GPS_MAP_KEY_UP,
+    OSM_GPS_MAP_KEY_DOWN,
+    OSM_GPS_MAP_KEY_LEFT,
+    OSM_GPS_MAP_KEY_RIGHT,
+    OSM_GPS_MAP_KEY_MAX
+} OsmGpsMapKey_t;
 
-#define OSM_GPS_MAP_INVALID  (0.0/0.0)
+#define OSM_GPS_MAP_INVALID         (0.0/0.0)
+#define OSM_GPS_MAP_CACHE_DISABLED  "none://"
+#define OSM_GPS_MAP_CACHE_AUTO      "auto://"
+#define OSM_GPS_MAP_CACHE_FRIENDLY  "friendly://"
 
 typedef struct {
     gint x, y, w, h;
@@ -127,6 +140,7 @@ typedef enum {
     OSM_GPS_MAP_BALLOON_EVENT_TYPE_DRAW,
     OSM_GPS_MAP_BALLOON_EVENT_TYPE_CLICK,
     OSM_GPS_MAP_BALLOON_EVENT_TYPE_REMOVED,
+    OSM_GPS_MAP_BALLOON_EVENT_TYPE_SIZE_REQUEST,
 } osm_gps_map_balloon_event_type_t;
 
 typedef struct {
@@ -147,37 +161,40 @@ typedef struct {
 typedef void (*OsmGpsMapBalloonCallback)(osm_gps_map_balloon_event_t *event, gpointer data);
 #define	OSM_GPS_MAP_BALLOON_CALLBACK(f) ((OsmGpsMapBalloonCallback) (f))
 
-GType osm_gps_map_get_type (void) G_GNUC_CONST;
+GType       osm_gps_map_get_type                    (void) G_GNUC_CONST;
 
-const char* osm_gps_map_source_get_friendly_name(OsmGpsMapSource_t source);
-const char* osm_gps_map_source_get_repo_uri(OsmGpsMapSource_t source);
-const char *osm_gps_map_source_get_image_format(OsmGpsMapSource_t source);
-int osm_gps_map_source_get_min_zoom(OsmGpsMapSource_t source);
-int osm_gps_map_source_get_max_zoom(OsmGpsMapSource_t source);
+GtkWidget*  osm_gps_map_new                         (void);
+
+char*       osm_gps_map_get_default_cache_directory (void);
+
+const char* osm_gps_map_source_get_friendly_name    (OsmGpsMapSource_t source);
+const char* osm_gps_map_source_get_repo_uri         (OsmGpsMapSource_t source);
+const char* osm_gps_map_source_get_image_format     (OsmGpsMapSource_t source);
+int         osm_gps_map_source_get_min_zoom         (OsmGpsMapSource_t source);
+int         osm_gps_map_source_get_max_zoom         (OsmGpsMapSource_t source);
+gboolean    osm_gps_map_source_is_valid             (OsmGpsMapSource_t source);
+
+void        osm_gps_map_download_maps               (OsmGpsMap *map, coord_t *pt1, coord_t *pt2, int zoom_start, int zoom_end);
+void        osm_gps_map_get_bbox                    (OsmGpsMap *map, coord_t *pt1, coord_t *pt2);
+void        osm_gps_map_set_mapcenter               (OsmGpsMap *map, float latitude, float longitude, int zoom);
+void        osm_gps_map_set_center                  (OsmGpsMap *map, float latitude, float longitude);
+int         osm_gps_map_set_zoom                    (OsmGpsMap *map, int zoom);
+void        osm_gps_map_add_track                   (OsmGpsMap *map, GSList *track);
+void        osm_gps_map_replace_track               (OsmGpsMap *map, GSList *old_track, GSList *new_track);
+void        osm_gps_map_clear_tracks                (OsmGpsMap *map);
+void        osm_gps_map_add_image                   (OsmGpsMap *map, float latitude, float longitude, GdkPixbuf *image);
+void        osm_gps_map_add_image_with_alignment    (OsmGpsMap *map, float latitude, float longitude, GdkPixbuf *image, float xalign, float yalign);
+gboolean    osm_gps_map_remove_image                (OsmGpsMap *map, GdkPixbuf *image);
+void        osm_gps_map_clear_images                (OsmGpsMap *map);
+void        osm_gps_map_draw_gps                    (OsmGpsMap *map, float latitude, float longitude, float heading);
+void        osm_gps_map_clear_gps                   (OsmGpsMap *map);
+coord_t     osm_gps_map_get_co_ordinates            (OsmGpsMap *map, int pixel_x, int pixel_y);
+void        osm_gps_map_screen_to_geographic        (OsmGpsMap *map, gint pixel_x, gint pixel_y, gfloat *latitude, gfloat *longitude);
+void        osm_gps_map_geographic_to_screen        (OsmGpsMap *map, gfloat latitude, gfloat longitude, gint *pixel_x, gint *pixel_y);
+void        osm_gps_map_scroll                      (OsmGpsMap *map, gint dx, gint dy);
+float       osm_gps_map_get_scale                   (OsmGpsMap *map);
+void        osm_gps_map_set_keyboard_shortcut       (OsmGpsMap *map, OsmGpsMapKey_t key, guint keyval);
 
-void osm_gps_map_download_maps (OsmGpsMap *map, coord_t *pt1, coord_t *pt2, int zoom_start, int zoom_end);
-void osm_gps_map_get_bbox (OsmGpsMap *map, coord_t *pt1, coord_t *pt2);
-void osm_gps_map_set_mapcenter (OsmGpsMap *map, float latitude, float longitude, int zoom);
-void osm_gps_map_set_center (OsmGpsMap *map, float latitude, float longitude);
-int osm_gps_map_set_zoom (OsmGpsMap *map, int zoom);
-void osm_gps_map_add_track (OsmGpsMap *map, GSList *track);
-void osm_gps_map_replace_track (OsmGpsMap *map, GSList *old_track, GSList *new_track);
-void osm_gps_map_clear_tracks (OsmGpsMap *map);
-void osm_gps_map_add_image (OsmGpsMap *map, float latitude, float longitude, GdkPixbuf *image);
-gboolean osm_gps_map_remove_image (OsmGpsMap *map, GdkPixbuf *image);
-void osm_gps_map_clear_images (OsmGpsMap *map);
-void osm_gps_map_draw_gps (OsmGpsMap *map, float latitude, float longitude, float heading);
-void osm_gps_map_clear_gps (OsmGpsMap *map);
-coord_t osm_gps_map_get_co_ordinates (OsmGpsMap *map, int pixel_x, int pixel_y);
-GtkWidget * osm_gps_map_new(void);
-void osm_gps_map_screen_to_geographic (OsmGpsMap *map,
-                                       gint pixel_x, gint pixel_y,
-                                       gfloat *latitude, gfloat *longitude);
-void osm_gps_map_geographic_to_screen (OsmGpsMap *map,
-                                       gfloat latitude, gfloat longitude,
-                                       gint *pixel_x, gint *pixel_y);
-void osm_gps_map_scroll (OsmGpsMap *map, gint dx, gint dy);
-float osm_gps_map_get_scale(OsmGpsMap *map);
 #ifdef ENABLE_OSD
 void osm_gps_map_register_osd(OsmGpsMap *map, osm_gps_map_osd_t *osd);
 void osm_gps_map_redraw (OsmGpsMap *map);
